@@ -5,7 +5,7 @@ use Bible::OBML;
 
 with 'Throwable';
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 has obml => ( is => 'ro', isa => 'Bible::OBML', default => sub { Bible::OBML->new } );
 
@@ -207,8 +207,9 @@ sub _html {
 
 __PACKAGE__->meta->make_immutable;
 1;
-__END__
+
 =pod
+
 =head1 NAME
 
 Bible::OBML::HTML - Render OBML as HTML
@@ -282,6 +283,13 @@ instance of L<Bible::OBML>.
 
 L<Bible::OBML>, L<Bible::OBML::Reference>.
 
+You can also look for information at:
+
+    GitHub: https://github.com/gryphonshafer/Bible-OBML
+    AnnoCPAN: http://annocpan.org/dist/Bible-OBML
+    CPAN Ratings: http://cpanratings.perl.org/m/Bible-OBML
+    Search CPAN: http://search.cpan.org/dist/Bible-OBML
+
 =head1 AUTHOR
 
 Gryphon Shafer E<lt>gryphon@cpan.orgE<gt>.
@@ -291,7 +299,6 @@ Gryphon Shafer E<lt>gryphon@cpan.orgE<gt>.
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.8.4 or,
-at your option, any later version of Perl 5 you may have available.
+it under the same terms as Perl itself.
 
 =cut
